==> idris-1.1.1-6-i686.pkg.tar.xz: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: idris
version: 1.1.1
id: idris-1.1.1-7HeT3SGez5k3eyYWGbRztb
key: idris-1.1.1-7HeT3SGez5k3eyYWGbRztb
license: BSD3
maintainer: Edwin Brady <eb@cs.st-andrews.ac.uk>
stability: Beta
homepage: http://www.idris-lang.org/
synopsis: Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <http://www.idris-lang.org/documentation>.
    Features include:
    .
    * Full, first class, dependent types with dependent pattern matching
    .
    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings
    .
    * Interfaces (similar to type classes), monad comprehensions
    .
    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs
    .
    * Totality checking
    .
    * Coinductive types
    .
    * Indentation significant syntax, extensible syntax
    .
    * Cumulative universes
    .
    * Simple foreign function interface (to C)
    .
    * Hugs style interactive environment
category: Compilers/Interpreters, Dependent Types
author: Edwin Brady
exposed: True
indefinite: False
exposed-modules:
    IRTS.BCImp IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Parser Idris.Parser.Data
    Idris.Parser.Expr Idris.Parser.Helpers Idris.Parser.Ops
    Idris.PartialEval Idris.Primitives Idris.ProofSearch Idris.Prover
    Idris.Providers Idris.REPL Idris.REPL.Browse Idris.REPL.Commands
    Idris.REPL.Parser Idris.Reflection Idris.Termination
    Idris.Transforms Idris.TypeSearch Idris.Unlit Idris.WhoCalls
    Util.DynamicLinker Util.ScreenSize Util.System
hidden-modules: Util.Pretty Util.Net Idris.Package.Parser
                Paths_idris Version_idris Tools_idris
abi: 47e6c5706f347553751fafbc1aabee78
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/idris-1.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/idris-1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/idris
hs-libraries: HSidris-1.1.1-7HeT3SGez5k3eyYWGbRztb
extra-libraries:
    gmp
depends:
    base-4.10.0.0 aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    annotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
    ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk array-0.5.2.0
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm binary-0.8.5.1
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL bytestring-0.10.8.2
    cheapskate-0.1.1-KyqgRaIkuVjELswiGOtPTm
    code-page-0.1.3-Lb49vTg78IDCCaaNT9XtlB containers-0.5.10.2
    deepseq-1.4.3.0 directory-1.3.0.2 filepath-1.4.1.2
    fingertree-0.1.1.0-AeB75WM6BG2IEoTBKBQuqQ haskeline-0.7.4.0
    ieee754-0.8.0-HLjs1Vz4yYwDDe3V5nl83v
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    parsers-0.12.7-1kfASGSbUOaHyymSJg92ek pretty-1.1.3.3
    process-1.6.1.0 regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
    terminal-size-0.3.2.1-3horyWZYbrD9bXg7iXYoCW
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    trifecta-1.7.1.1-JoE6evt9XU46Etc3OAcfAU
    uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD
    zip-archive-0.3.1.1-CZhWVZnrHky8oZZ6YlWuu5
    fsnotify-0.2.1.1-DlyPuusiJNu6JLzz0E0brN
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc unix-2.7.2.2
    libffi-0.1-Ee6b4wap395BBnyxOgVqYl
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             annotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC=9fa3d60a9e7f2c957d7e8d120bc3f791
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk=dd8d552288e499e2e21b7896e82609e8
             array-0.5.2.0=044554210403f250e868a2183de060a9
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             cheapskate-0.1.1-KyqgRaIkuVjELswiGOtPTm=3267c47e6ba36e450478b660224510e8
             code-page-0.1.3-Lb49vTg78IDCCaaNT9XtlB=50f3be7e05c03942f950eb5f5ca7566b
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             fingertree-0.1.1.0-AeB75WM6BG2IEoTBKBQuqQ=ea22e7daf4ce68536da76cf6a1713b7f
             haskeline-0.7.4.0=ee72a1e6f6c246132a6260bcf7bd279e
             ieee754-0.8.0-HLjs1Vz4yYwDDe3V5nl83v=642b6f988113e59a50a3d7c357032bce
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             parsers-0.12.7-1kfASGSbUOaHyymSJg92ek=28f5d89af564c00015ae8eb2097c2ac7
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             terminal-size-0.3.2.1-3horyWZYbrD9bXg7iXYoCW=8dc64bade0ea85d816efdeaa72b05d60
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             trifecta-1.7.1.1-JoE6evt9XU46Etc3OAcfAU=d38cf1b8146e80015c2526f13070b1fa
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD=23f06a84a106196e9d65f622e61b1fe6
             zip-archive-0.3.1.1-CZhWVZnrHky8oZZ6YlWuu5=501e3ecfee50c6fe29be73a20486bd3f
             fsnotify-0.2.1.1-DlyPuusiJNu6JLzz0E0brN=445d06348dcf50e4ef497755f40f35a8
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
             libffi-0.1-Ee6b4wap395BBnyxOgVqYl=db09c424fc376769887a056c84e358d0
haddock-interfaces: /usr/share/doc/idris/html/idris.haddock
haddock-html: /usr/share/doc/idris/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> idris-1.1.1-8-i686.pkg.tar.xz: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: idris
version: 1.1.1
id: idris-1.1.1-Ed96WgTbTtXEugQ24vhfJi
key: idris-1.1.1-Ed96WgTbTtXEugQ24vhfJi
license: BSD3
maintainer: Edwin Brady <eb@cs.st-andrews.ac.uk>
stability: Beta
homepage: http://www.idris-lang.org/
synopsis: Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <http://www.idris-lang.org/documentation>.
    Features include:
    .
    * Full, first class, dependent types with dependent pattern matching
    .
    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings
    .
    * Interfaces (similar to type classes), monad comprehensions
    .
    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs
    .
    * Totality checking
    .
    * Coinductive types
    .
    * Indentation significant syntax, extensible syntax
    .
    * Cumulative universes
    .
    * Simple foreign function interface (to C)
    .
    * Hugs style interactive environment
category: Compilers/Interpreters, Dependent Types
author: Edwin Brady
exposed: True
indefinite: False
exposed-modules:
    IRTS.BCImp IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Parser Idris.Parser.Data
    Idris.Parser.Expr Idris.Parser.Helpers Idris.Parser.Ops
    Idris.PartialEval Idris.Primitives Idris.ProofSearch Idris.Prover
    Idris.Providers Idris.REPL Idris.REPL.Browse Idris.REPL.Commands
    Idris.REPL.Parser Idris.Reflection Idris.Termination
    Idris.Transforms Idris.TypeSearch Idris.Unlit Idris.WhoCalls
    Util.DynamicLinker Util.ScreenSize Util.System
hidden-modules: Util.Pretty Util.Net Idris.Package.Parser
                Paths_idris Version_idris Tools_idris
abi: b3ec78ae1d4aeee0e99acf143d6417fa
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/idris-1.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/idris-1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/idris
hs-libraries: HSidris-1.1.1-Ed96WgTbTtXEugQ24vhfJi
extra-libraries:
    gmp
depends:
    base-4.10.0.0 aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    annotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
    ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk array-0.5.2.0
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm binary-0.8.5.1
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL bytestring-0.10.8.2
    cheapskate-0.1.1-KyqgRaIkuVjELswiGOtPTm
    code-page-0.1.3-Lb49vTg78IDCCaaNT9XtlB containers-0.5.10.2
    deepseq-1.4.3.0 directory-1.3.0.2 filepath-1.4.1.2
    fingertree-0.1.2.1-AdW3qo2F87f3RmpO72aWjC haskeline-0.7.4.0
    ieee754-0.8.0-HLjs1Vz4yYwDDe3V5nl83v
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    parsers-0.12.7-1kfASGSbUOaHyymSJg92ek pretty-1.1.3.3
    process-1.6.1.0 regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj
    terminal-size-0.3.2.1-3horyWZYbrD9bXg7iXYoCW
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    trifecta-1.7.1.1-I3RnAwxEfslH8J67w1Xzwa
    uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD
    zip-archive-0.3.1.1-CZhWVZnrHky8oZZ6YlWuu5
    fsnotify-0.2.1.1-DlyPuusiJNu6JLzz0E0brN
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc unix-2.7.2.2
    libffi-0.1-Ee6b4wap395BBnyxOgVqYl
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             annotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC=9fa3d60a9e7f2c957d7e8d120bc3f791
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk=dd8d552288e499e2e21b7896e82609e8
             array-0.5.2.0=044554210403f250e868a2183de060a9
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             cheapskate-0.1.1-KyqgRaIkuVjELswiGOtPTm=3267c47e6ba36e450478b660224510e8
             code-page-0.1.3-Lb49vTg78IDCCaaNT9XtlB=50f3be7e05c03942f950eb5f5ca7566b
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             fingertree-0.1.2.1-AdW3qo2F87f3RmpO72aWjC=70aa0767e1358904a5e3fc3803b7c4ef
             haskeline-0.7.4.0=ee72a1e6f6c246132a6260bcf7bd279e
             ieee754-0.8.0-HLjs1Vz4yYwDDe3V5nl83v=642b6f988113e59a50a3d7c357032bce
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             parsers-0.12.7-1kfASGSbUOaHyymSJg92ek=28f5d89af564c00015ae8eb2097c2ac7
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             regex-tdfa-1.2.2-1G5AA2OVGrl1AkVWQSHaiw=a4a19938ad7bbae62d09937bd32287f4
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             terminal-size-0.3.2.1-3horyWZYbrD9bXg7iXYoCW=8dc64bade0ea85d816efdeaa72b05d60
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             trifecta-1.7.1.1-I3RnAwxEfslH8J67w1Xzwa=e6ccbfc7963fbacd6a84218d93f347d1
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD=23f06a84a106196e9d65f622e61b1fe6
             zip-archive-0.3.1.1-CZhWVZnrHky8oZZ6YlWuu5=501e3ecfee50c6fe29be73a20486bd3f
             fsnotify-0.2.1.1-DlyPuusiJNu6JLzz0E0brN=445d06348dcf50e4ef497755f40f35a8
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
             libffi-0.1-Ee6b4wap395BBnyxOgVqYl=db09c424fc376769887a056c84e358d0
haddock-interfaces: /usr/share/doc/idris/html/idris.haddock
haddock-html: /usr/share/doc/idris/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
